@@ -12,8 +12,8 @@ The current release supports SLHA version 1. Assistance with supporting version
 2 will be gladly accepted!
 
 The plotting script provides output in PDF via LaTeX and the TikZ graphics package,
-as LaTeX/TikZ source for direct embedding into documents, and in the format used by
-the Rivet make-plots system.
+and as LaTeX/TikZ source for direct embedding into documents or user-tweaking of
+the generated output.
 
 TODOs:
  * Identify HERWIG decay matrix element to use in ISAWIG
@@ -23,7 +23,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "1.0.8"
+__version__ = "1.1.0"
 
 
 def _autotype(var):
@@ -84,6 +84,9 @@ class Block(object):
         s += str(self.entries)
         return s
 
+    def __repr__(self):
+        return self.__str__()
+
 
 class Decay(object):
     """
@@ -110,6 +113,9 @@ class Decay(object):
     def __str__(self):
         return "%e %s" % (self.br, self.ids)
 
+    def __repr__(self):
+        return self.__str__()
+
 
 class Particle(object):
     """
@@ -149,6 +155,10 @@ class Particle(object):
                 s += "\n  %s" % d
         return s
 
+    def __repr__(self):
+        return self.__str__()
+
+
 
 def readSLHAFile(spcfilename, **kwargs):
     """
@@ -252,6 +262,152 @@ def readISAWIGFile(isafilename, **kwargs):
     return rtn
 
 
+def writeSLHAFile(spcfilename, blocks, decays, **kwargs):
+    """
+    Write an SLHA file from the supplied blocks and decays dicts.
+
+    Other keyword parameters are passed to writeSLHA.
+    """
+    f = open(spcfilename, "w")
+    f.write(writeSLHA(blocks, decays, kwargs))
+    f.close()
+
+
+# TODO: Split writeSLHA into writeSLHA{Blocks,Decays}
+
+
+def writeSLHA(blocks, decays, ignorenobr=False):
+    """
+    Return an SLHA definition as a string, from the supplied blocks and decays dicts.
+    """
+    sep = "   "
+    out = ""
+    def dict_hier_strs(d, s=""):
+        if type(d) is dict:
+            for k, v in sorted(d.iteritems()):
+                for s2 in dict_hier_strs(v, s + sep + _autostr(k)):
+                    yield s2
+        else:
+            yield s + sep + _autostr(d)
+    ## Blocks
+    for bname, b in sorted(blocks.iteritems()):
+        namestr = b.name
+        if b.q is not None:
+            namestr += " Q= %e" % b.q
+        out += "BLOCK %s\n" % namestr
+        for s in dict_hier_strs(b.entries):
+            out += sep + s + "\n"
+        out += "\n"
+    ## Decays
+    for pid, particle in sorted(decays.iteritems()):
+        out += "DECAY %d %e\n" % (particle.pid, particle.totalwidth or -1)
+        for d in sorted(particle.decays):
+            if d.br > 0.0 or not ignorenobr:
+                products_str = "   ".join(map(str, d.ids))
+                out += sep + "%e" % d.br + sep + "%d" % len(d.ids) + sep + products_str + "\n"
+        out += "\n"
+    return out
+
+
+
+###############################################################################
+## ISAWIG handling
+
+## Static array of HERWIG IDHW codes mapped to PDG MC ID codes, based on
+## http://www.hep.phy.cam.ac.uk/~richardn/HERWIG/ISAWIG/susycodes.html
+## + the IDPDG array and section 4.13 of the HERWIG manual.
+_HERWIGID2PDGID = {}
+_HERWIGID2PDGID[7]   = -1
+_HERWIGID2PDGID[8]   = -2
+_HERWIGID2PDGID[9]   = -3
+_HERWIGID2PDGID[10]  = -4
+_HERWIGID2PDGID[11]  = -5
+_HERWIGID2PDGID[12]  = -6
+_HERWIGID2PDGID[13]  =  21
+_HERWIGID2PDGID[59]  =  22
+_HERWIGID2PDGID[121] =  11
+_HERWIGID2PDGID[122] =  12
+_HERWIGID2PDGID[123] =  13
+_HERWIGID2PDGID[124] =  14
+_HERWIGID2PDGID[125] =  15
+_HERWIGID2PDGID[126] =  16
+_HERWIGID2PDGID[127] = -11
+_HERWIGID2PDGID[128] = -12
+_HERWIGID2PDGID[129] = -13
+_HERWIGID2PDGID[130] = -14
+_HERWIGID2PDGID[131] = -15
+_HERWIGID2PDGID[132] = -16
+_HERWIGID2PDGID[203] =  25 ## HIGGSL0 (== PDG standard in this direction)
+_HERWIGID2PDGID[204] =  35 ## HIGGSH0
+_HERWIGID2PDGID[205] =  36 ## HIGGSA0
+_HERWIGID2PDGID[206] =  37 ## HIGGS+
+_HERWIGID2PDGID[207] = -37 ## HIGGS-
+_HERWIGID2PDGID[401] =  1000001 ## SSDLBR
+_HERWIGID2PDGID[407] = -1000001 ## SSDLBR
+_HERWIGID2PDGID[402] =  1000002 ## SSULBR
+_HERWIGID2PDGID[408] = -1000002 ## SSUL
+_HERWIGID2PDGID[403] =  1000003 ## SSSLBR
+_HERWIGID2PDGID[409] = -1000003 ## SSSL
+_HERWIGID2PDGID[404] =  1000004 ## SSCLBR
+_HERWIGID2PDGID[410] = -1000004 ## SSCL
+_HERWIGID2PDGID[405] =  1000005 ## SSB1BR
+_HERWIGID2PDGID[411] = -1000005 ## SSB1
+_HERWIGID2PDGID[406] =  1000006 ## SST1BR
+_HERWIGID2PDGID[412] = -1000006 ## SST1
+_HERWIGID2PDGID[413] =  2000001 ## SSDR
+_HERWIGID2PDGID[419] = -2000001 ## SSDRBR
+_HERWIGID2PDGID[414] =  2000002 ## SSUR
+_HERWIGID2PDGID[420] = -2000002 ## SSURBR
+_HERWIGID2PDGID[415] =  2000003 ## SSSR
+_HERWIGID2PDGID[421] = -2000003 ## SSSRBR
+_HERWIGID2PDGID[416] =  2000004 ## SSCR
+_HERWIGID2PDGID[422] = -2000004 ## SSCRBR
+_HERWIGID2PDGID[417] =  2000005 ## SSB2
+_HERWIGID2PDGID[423] = -2000005 ## SSB2BR
+_HERWIGID2PDGID[418] =  2000006 ## SST2
+_HERWIGID2PDGID[424] = -2000006 ## SST2BR
+_HERWIGID2PDGID[425] =  1000011 ## SSEL-
+_HERWIGID2PDGID[431] = -1000011 ## SSEL+
+_HERWIGID2PDGID[426] =  1000012 ## SSNUEL
+_HERWIGID2PDGID[432] = -1000012 ## SSNUELBR
+_HERWIGID2PDGID[427] =  1000013 ## SSMUL-
+_HERWIGID2PDGID[433] = -1000013 ## SSMUL+
+_HERWIGID2PDGID[428] =  1000014 ## SSNUMUL
+_HERWIGID2PDGID[434] = -1000014 ## SSNUMLBR
+_HERWIGID2PDGID[429] =  1000015 ## SSTAU1-
+_HERWIGID2PDGID[435] = -1000015 ## SSTAU1+
+_HERWIGID2PDGID[430] =  1000016 ## SSNUTL
+_HERWIGID2PDGID[436] = -1000016 ## SSNUTLBR
+_HERWIGID2PDGID[437] =  2000011 ## SSEL-
+_HERWIGID2PDGID[443] = -2000011 ## SSEL+
+_HERWIGID2PDGID[438] =  2000012 ## SSNUEL
+_HERWIGID2PDGID[444] = -2000012 ## SSNUELBR
+_HERWIGID2PDGID[439] =  2000013 ## SSMUL-
+_HERWIGID2PDGID[445] = -2000013 ## SSMUL+
+_HERWIGID2PDGID[440] =  2000014 ## SSNUMUL
+_HERWIGID2PDGID[446] = -2000014 ## SSNUMLBR
+_HERWIGID2PDGID[441] =  2000015 ## SSTAU1-
+_HERWIGID2PDGID[447] = -2000015 ## SSTAU1+
+_HERWIGID2PDGID[442] =  2000016 ## SSNUTL
+_HERWIGID2PDGID[448] = -2000016 ## SSNUTLBR
+_HERWIGID2PDGID[449] =  1000021 ## GLUINO
+_HERWIGID2PDGID[450] =  1000022 ## NTLINO1
+_HERWIGID2PDGID[451] =  1000023 ## NTLINO2
+_HERWIGID2PDGID[452] =  1000025 ## NTLINO3
+_HERWIGID2PDGID[453] =  1000035 ## NTLINO4
+_HERWIGID2PDGID[454] =  1000024 ## CHGINO1+
+_HERWIGID2PDGID[456] = -1000024 ## CHGINO1-
+_HERWIGID2PDGID[455] =  1000037 ## CHGINO2+
+_HERWIGID2PDGID[457] = -1000037 ## CHGINO2-
+_HERWIGID2PDGID[458] =  1000039 ## GRAVTINO
+
+def herwigid2pdgid(hwid):
+    """
+    Convert a particle ID code in the HERWIG internal IDHW format (as used by
+    ISAWIG) into its equivalent in the standard PDG ID code definition.
+    """
+    return _HERWIGID2PDGID.get(hwid, hwid)
+
 
 def readISAWIG(isastr, ignorenobr=False):
     """
@@ -267,93 +423,6 @@ def readISAWIG(isastr, ignorenobr=False):
     branching ratio of zero.
     """
 
-    ## PDG MC ID codes mapped to HERWIG IDHW codes, based on
-    ## http://www.hep.phy.cam.ac.uk/~richardn/HERWIG/ISAWIG/susycodes.html
-    ## + the IDPDG array and section 4.13 of the HERWIG manual.
-    HERWIGID2PDGID = {}
-    HERWIGID2PDGID[7]   = -1
-    HERWIGID2PDGID[8]   = -2
-    HERWIGID2PDGID[9]   = -3
-    HERWIGID2PDGID[10]  = -4
-    HERWIGID2PDGID[11]  = -5
-    HERWIGID2PDGID[12]  = -6
-    HERWIGID2PDGID[13]  =  21
-    HERWIGID2PDGID[59]  =  22
-    HERWIGID2PDGID[121] =  11
-    HERWIGID2PDGID[122] =  12
-    HERWIGID2PDGID[123] =  13
-    HERWIGID2PDGID[124] =  14
-    HERWIGID2PDGID[125] =  15
-    HERWIGID2PDGID[126] =  16
-    HERWIGID2PDGID[127] = -11
-    HERWIGID2PDGID[128] = -12
-    HERWIGID2PDGID[129] = -13
-    HERWIGID2PDGID[130] = -14
-    HERWIGID2PDGID[131] = -15
-    HERWIGID2PDGID[132] = -16
-    HERWIGID2PDGID[203] =  25 ## HIGGSL0 (== PDG standard in this direction)
-    HERWIGID2PDGID[204] =  35 ## HIGGSH0
-    HERWIGID2PDGID[205] =  36 ## HIGGSA0
-    HERWIGID2PDGID[206] =  37 ## HIGGS+
-    HERWIGID2PDGID[207] = -37 ## HIGGS-
-    HERWIGID2PDGID[401] =  1000001 ## SSDLBR
-    HERWIGID2PDGID[407] = -1000001 ## SSDLBR
-    HERWIGID2PDGID[402] =  1000002 ## SSULBR
-    HERWIGID2PDGID[408] = -1000002 ## SSUL
-    HERWIGID2PDGID[403] =  1000003 ## SSSLBR
-    HERWIGID2PDGID[409] = -1000003 ## SSSL
-    HERWIGID2PDGID[404] =  1000004 ## SSCLBR
-    HERWIGID2PDGID[410] = -1000004 ## SSCL
-    HERWIGID2PDGID[405] =  1000005 ## SSB1BR
-    HERWIGID2PDGID[411] = -1000005 ## SSB1
-    HERWIGID2PDGID[406] =  1000006 ## SST1BR
-    HERWIGID2PDGID[412] = -1000006 ## SST1
-    HERWIGID2PDGID[413] =  2000001 ## SSDR
-    HERWIGID2PDGID[419] = -2000001 ## SSDRBR
-    HERWIGID2PDGID[414] =  2000002 ## SSUR
-    HERWIGID2PDGID[420] = -2000002 ## SSURBR
-    HERWIGID2PDGID[415] =  2000003 ## SSSR
-    HERWIGID2PDGID[421] = -2000003 ## SSSRBR
-    HERWIGID2PDGID[416] =  2000004 ## SSCR
-    HERWIGID2PDGID[422] = -2000004 ## SSCRBR
-    HERWIGID2PDGID[417] =  2000005 ## SSB2
-    HERWIGID2PDGID[423] = -2000005 ## SSB2BR
-    HERWIGID2PDGID[418] =  2000006 ## SST2
-    HERWIGID2PDGID[424] = -2000006 ## SST2BR
-    HERWIGID2PDGID[425] =  1000011 ## SSEL-
-    HERWIGID2PDGID[431] = -1000011 ## SSEL+
-    HERWIGID2PDGID[426] =  1000012 ## SSNUEL
-    HERWIGID2PDGID[432] = -1000012 ## SSNUELBR
-    HERWIGID2PDGID[427] =  1000013 ## SSMUL-
-    HERWIGID2PDGID[433] = -1000013 ## SSMUL+
-    HERWIGID2PDGID[428] =  1000014 ## SSNUMUL
-    HERWIGID2PDGID[434] = -1000014 ## SSNUMLBR
-    HERWIGID2PDGID[429] =  1000015 ## SSTAU1-
-    HERWIGID2PDGID[435] = -1000015 ## SSTAU1+
-    HERWIGID2PDGID[430] =  1000016 ## SSNUTL
-    HERWIGID2PDGID[436] = -1000016 ## SSNUTLBR
-    HERWIGID2PDGID[437] =  2000011 ## SSEL-
-    HERWIGID2PDGID[443] = -2000011 ## SSEL+
-    HERWIGID2PDGID[438] =  2000012 ## SSNUEL
-    HERWIGID2PDGID[444] = -2000012 ## SSNUELBR
-    HERWIGID2PDGID[439] =  2000013 ## SSMUL-
-    HERWIGID2PDGID[445] = -2000013 ## SSMUL+
-    HERWIGID2PDGID[440] =  2000014 ## SSNUMUL
-    HERWIGID2PDGID[446] = -2000014 ## SSNUMLBR
-    HERWIGID2PDGID[441] =  2000015 ## SSTAU1-
-    HERWIGID2PDGID[447] = -2000015 ## SSTAU1+
-    HERWIGID2PDGID[442] =  2000016 ## SSNUTL
-    HERWIGID2PDGID[448] = -2000016 ## SSNUTLBR
-    HERWIGID2PDGID[449] =  1000021 ## GLUINO
-    HERWIGID2PDGID[450] =  1000022 ## NTLINO1
-    HERWIGID2PDGID[451] =  1000023 ## NTLINO2
-    HERWIGID2PDGID[452] =  1000025 ## NTLINO3
-    HERWIGID2PDGID[453] =  1000035 ## NTLINO4
-    HERWIGID2PDGID[454] =  1000024 ## CHGINO1+
-    HERWIGID2PDGID[456] = -1000024 ## CHGINO1-
-    HERWIGID2PDGID[455] =  1000037 ## CHGINO2+
-    HERWIGID2PDGID[457] = -1000037 ## CHGINO2-
-    HERWIGID2PDGID[458] =  1000039 ## GRAVTINO
 
     blocks = {}
     decays = {}
@@ -381,7 +450,7 @@ def readISAWIG(isastr, ignorenobr=False):
     for i in xrange(numentries):
         hwid, mass, lifetime = getnextvalidlineitems()
         width = 1.0/(lifetime * 1.51926778e24) ## width in GeV == hbar/lifetime in seconds
-        pdgid = HERWIGID2PDGID.get(hwid, hwid)
+        pdgid = herwigid2pdgid(hwid)
         masses.add_entry((pdgid, mass))
         decays[pdgid] = Particle(pdgid, width, mass)
         #print pdgid, mass, width
@@ -394,14 +463,14 @@ def readISAWIG(isastr, ignorenobr=False):
             #print n, numentries-1, d, numdecays-1
             decayitems = getnextvalidlineitems()
             hwid = decayitems[0]
-            pdgid = HERWIGID2PDGID.get(hwid, hwid)
+            pdgid = herwigid2pdgid(hwid)
             br = decayitems[1]
             nme = decayitems[2]
             daughter_hwids = decayitems[3:]
             daughter_pdgids = []
             for hw in daughter_hwids:
                 if hw != 0:
-                    daughter_pdgids.append(HERWIGID2PDGID.get(hw, hw))
+                    daughter_pdgids.append(herwigid2pdgid(hw))
             if not decays.has_key(pdgid):
                 #print "Decay for unlisted particle %d, %d" % (hwid, pdgid)
                 decays[pdgid] = Particle(pdgid)
@@ -468,52 +537,103 @@ def readISAWIG(isastr, ignorenobr=False):
     return blocks, decays
 
 
-def writeSLHAFile(spcfilename, blocks, decays, **kwargs):
+## PDG MC ID codes mapped to HERWIG IDHW codes, based on
+## http://www.hep.phy.cam.ac.uk/~richardn/HERWIG/ISAWIG/susycodes.html
+## + the IDPDG array and section 4.13 of the HERWIG manual.
+_PDGID2HERWIGID = {}
+_PDGID2HERWIGID[      -1] = 7
+_PDGID2HERWIGID[      -2] = 8
+_PDGID2HERWIGID[      -3] = 9
+_PDGID2HERWIGID[      -4] = 10
+_PDGID2HERWIGID[      -5] = 11
+_PDGID2HERWIGID[      -6] = 12
+_PDGID2HERWIGID[      21] = 13
+_PDGID2HERWIGID[      22] = 59
+_PDGID2HERWIGID[      11] = 121
+_PDGID2HERWIGID[      12] = 122
+_PDGID2HERWIGID[      13] = 123
+_PDGID2HERWIGID[      14] = 124
+_PDGID2HERWIGID[      15] = 125
+_PDGID2HERWIGID[      16] = 126
+_PDGID2HERWIGID[     -11] = 127
+_PDGID2HERWIGID[     -12] = 128
+_PDGID2HERWIGID[     -13] = 129
+_PDGID2HERWIGID[     -14] = 130
+_PDGID2HERWIGID[     -15] = 131
+_PDGID2HERWIGID[     -16] = 132
+_PDGID2HERWIGID[      25] = 203 ## HIGGSL0 (added for PDG standard -> HERWIG IDHW)
+_PDGID2HERWIGID[      26] = 203 ## HIGGSL0
+_PDGID2HERWIGID[      35] = 204 ## HIGGSH0
+_PDGID2HERWIGID[      36] = 205 ## HIGGSA0
+_PDGID2HERWIGID[      37] = 206 ## HIGGS+
+_PDGID2HERWIGID[     -37] = 207 ## HIGGS-
+_PDGID2HERWIGID[ 1000001] = 401 ## SSDLBR
+_PDGID2HERWIGID[-1000001] = 407 ## SSDLBR
+_PDGID2HERWIGID[ 1000002] = 402 ## SSULBR
+_PDGID2HERWIGID[-1000002] = 408 ## SSUL
+_PDGID2HERWIGID[ 1000003] = 403 ## SSSLBR
+_PDGID2HERWIGID[-1000003] = 409 ## SSSL
+_PDGID2HERWIGID[ 1000004] = 404 ## SSCLBR
+_PDGID2HERWIGID[-1000004] = 410 ## SSCL
+_PDGID2HERWIGID[ 1000005] = 405 ## SSB1BR
+_PDGID2HERWIGID[-1000005] = 411 ## SSB1
+_PDGID2HERWIGID[ 1000006] = 406 ## SST1BR
+_PDGID2HERWIGID[-1000006] = 412 ## SST1
+_PDGID2HERWIGID[ 2000001] = 413 ## SSDR
+_PDGID2HERWIGID[-2000001] = 419 ## SSDRBR
+_PDGID2HERWIGID[ 2000002] = 414 ## SSUR
+_PDGID2HERWIGID[-2000002] = 420 ## SSURBR
+_PDGID2HERWIGID[ 2000003] = 415 ## SSSR
+_PDGID2HERWIGID[-2000003] = 421 ## SSSRBR
+_PDGID2HERWIGID[ 2000004] = 416 ## SSCR
+_PDGID2HERWIGID[-2000004] = 422 ## SSCRBR
+_PDGID2HERWIGID[ 2000005] = 417 ## SSB2
+_PDGID2HERWIGID[-2000005] = 423 ## SSB2BR
+_PDGID2HERWIGID[ 2000006] = 418 ## SST2
+_PDGID2HERWIGID[-2000006] = 424 ## SST2BR
+_PDGID2HERWIGID[ 1000011] = 425 ## SSEL-
+_PDGID2HERWIGID[-1000011] = 431 ## SSEL+
+_PDGID2HERWIGID[ 1000012] = 426 ## SSNUEL
+_PDGID2HERWIGID[-1000012] = 432 ## SSNUELBR
+_PDGID2HERWIGID[ 1000013] = 427 ## SSMUL-
+_PDGID2HERWIGID[-1000013] = 433 ## SSMUL+
+_PDGID2HERWIGID[ 1000014] = 428 ## SSNUMUL
+_PDGID2HERWIGID[-1000014] = 434 ## SSNUMLBR
+_PDGID2HERWIGID[ 1000015] = 429 ## SSTAU1-
+_PDGID2HERWIGID[-1000015] = 435 ## SSTAU1+
+_PDGID2HERWIGID[ 1000016] = 430 ## SSNUTL
+_PDGID2HERWIGID[-1000016] = 436 ## SSNUTLBR
+_PDGID2HERWIGID[ 2000011] = 437 ## SSEL-
+_PDGID2HERWIGID[-2000011] = 443 ## SSEL+
+_PDGID2HERWIGID[ 2000012] = 438 ## SSNUEL
+_PDGID2HERWIGID[-2000012] = 444 ## SSNUELBR
+_PDGID2HERWIGID[ 2000013] = 439 ## SSMUL-
+_PDGID2HERWIGID[-2000013] = 445 ## SSMUL+
+_PDGID2HERWIGID[ 2000014] = 440 ## SSNUMUL
+_PDGID2HERWIGID[-2000014] = 446 ## SSNUMLBR
+_PDGID2HERWIGID[ 2000015] = 441 ## SSTAU1-
+_PDGID2HERWIGID[-2000015] = 447 ## SSTAU1+
+_PDGID2HERWIGID[ 2000016] = 442 ## SSNUTL
+_PDGID2HERWIGID[-2000016] = 448 ## SSNUTLBR
+_PDGID2HERWIGID[ 1000021] = 449 ## GLUINO
+_PDGID2HERWIGID[ 1000022] = 450 ## NTLINO1
+_PDGID2HERWIGID[ 1000023] = 451 ## NTLINO2
+_PDGID2HERWIGID[ 1000025] = 452 ## NTLINO3
+_PDGID2HERWIGID[ 1000035] = 453 ## NTLINO4
+_PDGID2HERWIGID[ 1000024] = 454 ## CHGINO1+
+_PDGID2HERWIGID[-1000024] = 456 ## CHGINO1-
+_PDGID2HERWIGID[ 1000037] = 455 ## CHGINO2+
+_PDGID2HERWIGID[-1000037] = 457 ## CHGINO2-
+_PDGID2HERWIGID[ 1000039] = 458 ## GRAVTINO
+
+def pdgid2herwigid(pdgid):
     """
-    Write an SLHA file from the supplied blocks and decays dicts.
-
-    Other keyword parameters are passed to writeSLHA.
+    Convert a particle ID code in the standard PDG ID code definition into
+    its equivalent in the HERWIG internal IDHW format (as used by ISAWIG).
     """
-    f = open(spcfilename, "w")
-    f.write(writeSLHA(blocks, decays, kwargs))
-    f.close()
+    return _PDGID2HERWIGID.get(pdgid, pdgid)
 
 
-# TODO: Split writeSLHA into writeSLHA{Blocks,Decays}
-
-
-def writeSLHA(blocks, decays, ignorenobr=False):
-    """
-    Return an SLHA definition as a string, from the supplied blocks and decays dicts.
-    """
-    sep = "   "
-    out = ""
-    def dict_hier_strs(d, s=""):
-        if type(d) is dict:
-            for k, v in sorted(d.iteritems()):
-                for s2 in dict_hier_strs(v, s + sep + _autostr(k)):
-                    yield s2
-        else:
-            yield s + sep + _autostr(d)
-    ## Blocks
-    for bname, b in sorted(blocks.iteritems()):
-        namestr = b.name
-        if b.q is not None:
-            namestr += " Q= %e" % b.q
-        out += "BLOCK %s\n" % namestr
-        for s in dict_hier_strs(b.entries):
-            out += sep + s + "\n"
-        out += "\n"
-    ## Decays
-    for pid, particle in sorted(decays.iteritems()):
-        out += "DECAY %d %e\n" % (particle.pid, particle.totalwidth or -1)
-        for d in sorted(particle.decays):
-            if d.br > 0.0 or not ignorenobr:
-                products_str = "   ".join(map(str, d.ids))
-                out += sep + "%e" % d.br + sep + "%d" % len(d.ids) + sep + products_str + "\n"
-        out += "\n"
-    return out
-
 
 
 def writeISAWIGFile(isafilename, blocks, decays, **kwargs):
@@ -539,94 +659,6 @@ def writeISAWIG(blocks, decays, ignorenobr=False):
     If the ignorenobr parameter is True, do not write decay entries with a
     branching ratio of zero.
     """
-    ## PDG MC ID codes mapped to HERWIG IDHW codes, based on
-    ## http://www.hep.phy.cam.ac.uk/~richardn/HERWIG/ISAWIG/susycodes.html
-    ## + the IDPDG array and section 4.13 of the HERWIG manual.
-    PDGID2HERWIGID = {}
-    PDGID2HERWIGID[      -1] = 7
-    PDGID2HERWIGID[      -2] = 8
-    PDGID2HERWIGID[      -3] = 9
-    PDGID2HERWIGID[      -4] = 10
-    PDGID2HERWIGID[      -5] = 11
-    PDGID2HERWIGID[      -6] = 12
-    PDGID2HERWIGID[      21] = 13
-    PDGID2HERWIGID[      22] = 59
-    PDGID2HERWIGID[      11] = 121
-    PDGID2HERWIGID[      12] = 122
-    PDGID2HERWIGID[      13] = 123
-    PDGID2HERWIGID[      14] = 124
-    PDGID2HERWIGID[      15] = 125
-    PDGID2HERWIGID[      16] = 126
-    PDGID2HERWIGID[     -11] = 127
-    PDGID2HERWIGID[     -12] = 128
-    PDGID2HERWIGID[     -13] = 129
-    PDGID2HERWIGID[     -14] = 130
-    PDGID2HERWIGID[     -15] = 131
-    PDGID2HERWIGID[     -16] = 132
-    PDGID2HERWIGID[      25] = 203 ## HIGGSL0 (added for PDG standard -> HERWIG IDHW)
-    PDGID2HERWIGID[      26] = 203 ## HIGGSL0
-    PDGID2HERWIGID[      35] = 204 ## HIGGSH0
-    PDGID2HERWIGID[      36] = 205 ## HIGGSA0
-    PDGID2HERWIGID[      37] = 206 ## HIGGS+
-    PDGID2HERWIGID[     -37] = 207 ## HIGGS-
-    PDGID2HERWIGID[ 1000001] = 401 ## SSDLBR
-    PDGID2HERWIGID[-1000001] = 407 ## SSDLBR
-    PDGID2HERWIGID[ 1000002] = 402 ## SSULBR
-    PDGID2HERWIGID[-1000002] = 408 ## SSUL
-    PDGID2HERWIGID[ 1000003] = 403 ## SSSLBR
-    PDGID2HERWIGID[-1000003] = 409 ## SSSL
-    PDGID2HERWIGID[ 1000004] = 404 ## SSCLBR
-    PDGID2HERWIGID[-1000004] = 410 ## SSCL
-    PDGID2HERWIGID[ 1000005] = 405 ## SSB1BR
-    PDGID2HERWIGID[-1000005] = 411 ## SSB1
-    PDGID2HERWIGID[ 1000006] = 406 ## SST1BR
-    PDGID2HERWIGID[-1000006] = 412 ## SST1
-    PDGID2HERWIGID[ 2000001] = 413 ## SSDR
-    PDGID2HERWIGID[-2000001] = 419 ## SSDRBR
-    PDGID2HERWIGID[ 2000002] = 414 ## SSUR
-    PDGID2HERWIGID[-2000002] = 420 ## SSURBR
-    PDGID2HERWIGID[ 2000003] = 415 ## SSSR
-    PDGID2HERWIGID[-2000003] = 421 ## SSSRBR
-    PDGID2HERWIGID[ 2000004] = 416 ## SSCR
-    PDGID2HERWIGID[-2000004] = 422 ## SSCRBR
-    PDGID2HERWIGID[ 2000005] = 417 ## SSB2
-    PDGID2HERWIGID[-2000005] = 423 ## SSB2BR
-    PDGID2HERWIGID[ 2000006] = 418 ## SST2
-    PDGID2HERWIGID[-2000006] = 424 ## SST2BR
-    PDGID2HERWIGID[ 1000011] = 425 ## SSEL-
-    PDGID2HERWIGID[-1000011] = 431 ## SSEL+
-    PDGID2HERWIGID[ 1000012] = 426 ## SSNUEL
-    PDGID2HERWIGID[-1000012] = 432 ## SSNUELBR
-    PDGID2HERWIGID[ 1000013] = 427 ## SSMUL-
-    PDGID2HERWIGID[-1000013] = 433 ## SSMUL+
-    PDGID2HERWIGID[ 1000014] = 428 ## SSNUMUL
-    PDGID2HERWIGID[-1000014] = 434 ## SSNUMLBR
-    PDGID2HERWIGID[ 1000015] = 429 ## SSTAU1-
-    PDGID2HERWIGID[-1000015] = 435 ## SSTAU1+
-    PDGID2HERWIGID[ 1000016] = 430 ## SSNUTL
-    PDGID2HERWIGID[-1000016] = 436 ## SSNUTLBR
-    PDGID2HERWIGID[ 2000011] = 437 ## SSEL-
-    PDGID2HERWIGID[-2000011] = 443 ## SSEL+
-    PDGID2HERWIGID[ 2000012] = 438 ## SSNUEL
-    PDGID2HERWIGID[-2000012] = 444 ## SSNUELBR
-    PDGID2HERWIGID[ 2000013] = 439 ## SSMUL-
-    PDGID2HERWIGID[-2000013] = 445 ## SSMUL+
-    PDGID2HERWIGID[ 2000014] = 440 ## SSNUMUL
-    PDGID2HERWIGID[-2000014] = 446 ## SSNUMLBR
-    PDGID2HERWIGID[ 2000015] = 441 ## SSTAU1-
-    PDGID2HERWIGID[-2000015] = 447 ## SSTAU1+
-    PDGID2HERWIGID[ 2000016] = 442 ## SSNUTL
-    PDGID2HERWIGID[-2000016] = 448 ## SSNUTLBR
-    PDGID2HERWIGID[ 1000021] = 449 ## GLUINO
-    PDGID2HERWIGID[ 1000022] = 450 ## NTLINO1
-    PDGID2HERWIGID[ 1000023] = 451 ## NTLINO2
-    PDGID2HERWIGID[ 1000025] = 452 ## NTLINO3
-    PDGID2HERWIGID[ 1000035] = 453 ## NTLINO4
-    PDGID2HERWIGID[ 1000024] = 454 ## CHGINO1+
-    PDGID2HERWIGID[-1000024] = 456 ## CHGINO1-
-    PDGID2HERWIGID[ 1000037] = 455 ## CHGINO2+
-    PDGID2HERWIGID[-1000037] = 457 ## CHGINO2-
-    PDGID2HERWIGID[ 1000039] = 458 ## GRAVTINO
 
     masses = blocks["MASS"].entries
 
@@ -648,7 +680,7 @@ def writeISAWIG(blocks, decays, ignorenobr=False):
                 lifetime = 1.0/(width * 1.51926778e24) ## lifetime in seconds == hbar/width in GeV
         except:
             pass
-        massout += "%d %e %e\n" % (PDGID2HERWIGID.get(pid, pid), masses[pid], lifetime)
+        massout += "%d %e %e\n" % (pdgid2herwigid(pid), masses[pid], lifetime)
     out += "%d\n" % massout.count("\n")
     out += massout
 
@@ -665,7 +697,7 @@ def writeISAWIG(blocks, decays, ignorenobr=False):
     for i, pid in enumerate(decays.keys()):
         # if not decays.has_key(pid):
         #     continue
-        hwid = PDGID2HERWIGID.get(pid, pid)
+        hwid = pdgid2herwigid(pid)
         decayout = ""
         #decayout += "@@@@ %d %d %d\n" % (i, pid, hwid)
         for i_d, d in enumerate(decays[pid].decays):
